@@ -3,8 +3,8 @@ django-formfield
 """
 __version_info__ = {
     'major': 0,
-    'minor': 1,
-    'micro': 3,
+    'minor': 2,
+    'micro': 0,
     'releaselevel': 'final',
     'serial': 1
 }
@@ -26,5 +26,5 @@ __version__ = get_version()
 
 try:
     from .fields import FormField, ModelFormField
-except ImportError:
+except (Exception, ):
     pass
